# Generated by Django 3.2.13 on 2022-04-22 08:49

from django.db import migrations, models

import mozilla_django_oidc_db.models


class Migration(migrations.Migration):
    dependencies = [
        ("mozilla_django_oidc_db", "0007_auto_20220307_1128"),
    ]

    operations = [
        migrations.AlterField(
            model_name="openidconnectconfig",
            name="claim_mapping",
            field=models.JSONField(
                default=mozilla_django_oidc_db.models.get_claim_mapping,
                help_text="Mapping from user-model fields to OIDC claims",
                verbose_name="claim mapping",
            ),
        ),
        migrations.AlterField(
            model_name="openidconnectconfig",
            name="oidc_op_jwks_endpoint",
            field=models.URLField(
                blank=True,
                help_text="URL of your OpenID Connect provider JSON Web Key Set endpoint. Required if `RS256` is used as signing algorithm.",
                max_length=1000,
                verbose_name="JSON Web Key Set endpoint",
            ),
        ),
        migrations.AlterField(
            model_name="openidconnectconfig",
            name="oidc_rp_idp_sign_key",
            field=models.CharField(
                blank=True,
                help_text="Key the Identity Provider uses to sign ID tokens in the case of an RSA sign algorithm. Should be the signing key in PEM or DER format.",
                max_length=1000,
                verbose_name="Sign key",
            ),
        ),
    ]
