# Generated by Django 2.2.24 on 2021-11-23 14:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("mozilla_django_oidc_db", "0004_auto_20210812_1044"),
    ]

    operations = [
        migrations.AddField(
            model_name="openidconnectconfig",
            name="sync_groups_glob_pattern",
            field=models.CharField(
                default="*",
                help_text="The glob pattern that groups must match to be synchronized to the local database.",
                max_length=255,
                verbose_name="groups glob pattern",
            ),
        ),
    ]
