# Generated by Django 2.2.24 on 2021-07-16 12:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("mozilla_django_oidc_db", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="openidconnectconfig",
            name="oidc_op_discovery_endpoint",
            field=models.URLField(
                blank=True,
                help_text="URL of your OpenID Connect provider discovery endpoint. If this is provided, the remaining endpoints can be omitted, as they will be derived from this endpoint.",
                max_length=1000,
                verbose_name="Discovery endpoint",
            ),
        ),
    ]
